@@ -765,9 +765,10 @@ __END__
 
 =head1 NAME
 
-Sim::OPT::Interlinear.
+Sim::OPT::Interlinear
 
 =head1 SYNOPSIS
+
   From Perl (via "re.pl" or in a Perl program):
   interlinear( "/path/to/a/pre-prepared-configfile.pl", "/path/to/a/pre-prepared-sourcefile.csv" );
 
@@ -781,39 +782,66 @@ Sim::OPT::Interlinear.
 
 =head1 DESCRIPTION
 
-Interlinear is a program for computing the missing values in multivariate datasieries pre-prepared in csv format.
-The program adopts a mix of nearest-neighbour strategy and linear interpolation for filling the missing values.
-A configuration file should be prepared following the example in the "examples" folder in this distribution.
-If the configuration file is incomplete or missing, the program adopts its own defaults; which presently include a sequence of loops constituted by three passes of linear interpolation and one of the nearest neighbor strategy.
+Interlinear is a program for computing the missing values in multivariate data series pre-prepared in csv format.
+
+
+Presently the program adopts a mix of nearest-neighbour strategy and hybrid linear interpolation for filling the missing values.
+
+A configuration file for the program should be prepared following the example in the "examples" folder in this distribution.
+
+If the configuration file is incomplete or missing, the program adopts its own defaults; which presently include a sequence of loops constituted by three passes of pure linear interpolation and one of the nearest neighbor strategy.
+
 The operations entailed are linear but the results of their interplay  are not.
+
 The operations can be weighted and the strategies can be intermixed.
-Other strategies are on the way to be implemented.
+
 The source cvs file has currently to be prepared in the format liked by Sim::OPT.
-For example, a multivatiate dataseries with missing entries (in which the numbers of the factors are put into the odd colums and the numbers of the levels are put in the even cdirectoryolums, and in which the last column is kept for the objective function), like the one shown below...
+
+For example, a multivatiate dataseries with missing entries, like the one shown below (in which the numbers relative to the factors are put into the odd colums and the numbers relative to the levels are put in the even columns, and in which the last column is kept for the objective function)...
+
 
 1,1,2,1,3,1,1.234
+
 1,1,2,2,3,2,1.500
+
 1,1,2,3,3,3
+
 1,2,2,1,3,1,1.534
+
 1,2,2,2,3,2,0.000
+
 1,2,2,3,3,0.550
+
 1,3,2,1,3,1
-1,3,2,2,3,2,0.670directory
+
+1,3,2,2,3,2,0.670
+
 1,3,2,3,3,3
 
+
 ...should be edited in the following manner:
 
+
 1-1_2-1_3-1,9.234
+
 1-1_2-2_3-2,4.500
+
 1-1_2-3_3-3
+
 1-2_2-1_3-1,7.534
+
 1-2_2-2_3-2,0.000
+
 1-2_2-3_3-3,0.550
+
 1-3_2-1_3-1
+
 1-3_2-2_3-2,0.670
+
 1-3_2-3_3-3
 
-After some computations, the program will outputs a new dataseries, with the missing values filled in.
+
+After some computations, the program will output a new dataseries, with the missing values filled in.
 
 
 =head2 EXPORT
