@@ -33,8 +33,7 @@ use Sim::OPT::Morph;
 use Sim::OPT::Report;
 use Sim::OPT::Descend;
 use Sim::OPT::Takechance;
-use Sim::OPT::Modish;
-use Parallel::ForkManager;
+#use Parallel::ForkManager;
 no strict; 
 no warnings;
 use warnings::unused;
